==> tentackle-swing-2.0.4-sources.jar: org/tentackle/swing/FormTableUtilityPopupFactory.java <==
/**
 * Tentackle - http://www.tentackle.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */



package org.tentackle.swing;

import org.tentackle.common.ServiceFactory;


interface FormTableUtilityPopupFactory$Singleton {
  static FormTableUtilityPopupFactory INSTANCE = ServiceFactory.createService(
              FormTableUtilityPopupFactory.class, DefaultFormTableUtilityPopupFactory.class);
}


/**
 * Factory for {@link FormTableUtilityPopup}s.
 *
 * @author harald
 */
public interface FormTableUtilityPopupFactory {


  /**
   * The singleton.
   *
   * @return the singleton
   */
  static FormTableUtilityPopupFactory getInstance() {
    return FormTableUtilityPopupFactory$Singleton.INSTANCE;
  }


  /**
   * Creates a popup.
   *
   * @return the popup
   */
  FormTableUtilityPopup createPopup();

}

==> tentackle-swing-2.0.6-sources.jar: org/tentackle/swing/FormTableUtilityPopupFactory.java <==
/**
 * Tentackle - http://www.tentackle.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */



package org.tentackle.swing;

import org.tentackle.common.ServiceFactory;


interface FormTableUtilityPopupFactory$Singleton {
  FormTableUtilityPopupFactory INSTANCE = ServiceFactory.createService(
              FormTableUtilityPopupFactory.class, DefaultFormTableUtilityPopupFactory.class);
}


/**
 * Factory for {@link FormTableUtilityPopup}s.
 *
 * @author harald
 */
public interface FormTableUtilityPopupFactory {


  /**
   * The singleton.
   *
   * @return the singleton
   */
  static FormTableUtilityPopupFactory getInstance() {
    return FormTableUtilityPopupFactory$Singleton.INSTANCE;
  }


  /**
   * Creates a popup.
   *
   * @return the popup
   */
  FormTableUtilityPopup createPopup();

}
